summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJoe McGill <jmcgill@us.ibm.com>2018-01-04 14:20:10 -0600
committerSachin Gupta <sgupta2m@in.ibm.com>2018-01-13 21:38:44 -0500
commita95f3b5f7c115eee188fa64a9da0a8f7f7731c07 (patch)
tree2bc150a9cf4c9ed1f221a11fa65decac387a59f3
parentf55ed0656b82e5f9381e0fd8eefe935ca9611c0d (diff)
downloadtalos-sbe-a95f3b5f7c115eee188fa64a9da0a8f7f7731c07.tar.gz
talos-sbe-a95f3b5f7c115eee188fa64a9da0a8f7f7731c07.zip
fix ADU setup for MCD disabled operation
Change-Id: I0068d797ad4a82216e440f701c5182ad95584a15 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/51503 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Dean Sanner <dsanner@us.ibm.com> Reviewed-by: Thi N. Tran <thi@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com> Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/51504 Reviewed-by: Sachin Gupta <sgupta2m@in.ibm.com>
-rw-r--r--src/import/chips/p9/procedures/hwp/nest/p9_adu_coherent_utils.C4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/import/chips/p9/procedures/hwp/nest/p9_adu_coherent_utils.C b/src/import/chips/p9/procedures/hwp/nest/p9_adu_coherent_utils.C
index dfc7c33f..737e3881 100644
--- a/src/import/chips/p9/procedures/hwp/nest/p9_adu_coherent_utils.C
+++ b/src/import/chips/p9/procedures/hwp/nest/p9_adu_coherent_utils.C
@@ -398,8 +398,8 @@ extern "C"
{
var_PU_ALTD_CMD_REG_FBC_TTYPE = ALTD_CMD_TTYPE_DMA_PR_WR;
- //Set scope to group scope
- altd_cmd_reg_data.insertFromRight<PU_ALTD_CMD_REG_FBC_SCOPE, PU_ALTD_CMD_REG_FBC_SCOPE_LEN>(ALTD_CMD_SCOPE_GROUP);
+ //Set scope to system scope
+ altd_cmd_reg_data.insertFromRight<PU_ALTD_CMD_REG_FBC_SCOPE, PU_ALTD_CMD_REG_FBC_SCOPE_LEN>(ALTD_CMD_SCOPE_SYSTEM);
// Set TSIZE
if ( l_transSize == p9_ADU_oper_flag::TSIZE_1 )
OpenPOWER on IntegriCloud